"""
Configuration for each algorithm
"""

from .federated import *
from .iceadmm import *
from .iiadmm import *
